==> kdevelop-4.7.0.tar.xz: kdevelop-4.7.0/projectmanagers/custommake/kdevcustommakemanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Custom Makefile Project Manager
Name[bs]=Korisnički Makefile menadžer projekta
Name[ca]=Gestor de projecte personalitzat Makefile
Name[ca@valencia]=Gestor de projecte personalitzat Makefile
Name[da]=Projekthåndtering med hjemmelavet Makefile
Name[de]=Projektverwaltung mit eigenem Makefile
Name[el]=Διαχειριστής έργου προσαρμοσμένου Makefile
Name[en_GB]=Custom Makefile Project Manager
Name[es]=Gestor de proyectos Makefile personalizados
Name[et]=Kohandatud Makefile'i projektihaldur
Name[fi]=Räätälöity Makefile-projektihallinta
Name[fr]=Gestionnaire de projets Makefiles personnalisés
Name[gl]=Xestor de proxectos con Makefile personalizado
Name[hu]=Egyéni makefájl projektkezelő
Name[it]=Gestore progetto Makefile personalizzato
Name[ja]=カスタム Makefile プロジェクトマネージャ
Name[kk]=Өзгеше Makefile жоба менеджері
Name[nb]=Prosjektstyring for egendefinerte Makefile-prosjekter
Name[nds]=Egen-Makefile-Projektpleger
Name[nl]=Aangepaste projectbeheerder voor makefile
Name[pl]=Zarządzanie własnym systemem budowania
Name[pt]=Gestor de Projectos de Makefiles Personalizadas
Name[pt_BR]=Gerenciador de Projeto personalizado do Makefile
Name[ru]=Управление проектами с собственным Makefile
Name[sk]=Správca projektu vlastného makefile
Name[sl]=Upravljalnik projekta z datoteko Makefile po meri
Name[sv]=Projekthantering av egna Make-filer
Name[tr]=Özel Makefile Proje Yönetici
Name[ug]=ئىختىيارى Makefile قۇرۇلۇش باشقۇرغۇ
Name[uk]=Керування проектами з власним Makefile
Name[x-test]=xxCustom Makefile Project Managerxx
Name[zh_CN]=自定义 Makefile 工程管理器
Name[zh_TW]=自訂 Makefile 專案管理員
GenericName=Project Manager
GenericName[bs]=Rukovodilac projekta
GenericName[ca]=Gestor de projectes
GenericName[ca@valencia]=Gestor de projectes
GenericName[cs]=Správce projektů
GenericName[da]=Projekthåndtering
GenericName[de]=Projektverwaltung
GenericName[el]=Διαχειριστής έργου
GenericName[en_GB]=Project Manager
GenericName[eo]=Projektadministrilo
GenericName[es]=Gestor de proyectos
GenericName[et]=Projektihaldur
GenericName[fi]=Projektihallinta
GenericName[fr]=Gestionnaire de projets
GenericName[ga]=Bainisteoir Tionscadail
GenericName[gl]=Xestor de proxectos
GenericName[hu]=Projektkezelő
GenericName[it]=Gestore progetto
GenericName[ja]=プロジェクトマネージャ
GenericName[kk]=Жоба менеджері
GenericName[km]=កម្មវិធី​គ្រប់គ្រង​គម្រោង
GenericName[nb]=Prosjektbehandler
GenericName[nds]=Projektpleger
GenericName[nl]=Projectbeheerder
GenericName[nn]=Prosjekthandsamar
GenericName[pl]=Zarządzanie projektami
GenericName[pt]=Gestor de Projectos
GenericName[pt_BR]=Gerenciador de Projetos
GenericName[ru]=Управление проектами
GenericName[sk]=Správca projektu
GenericName[sl]=Upravljalnik projektov
GenericName[sv]=Projekthantering
GenericName[tr]=Proje Yönetici
GenericName[ug]=قۇرۇلۇش باشقۇرغۇچ
GenericName[uk]=Керування проектами
GenericName[x-test]=xxProject Managerxx
GenericName[zh_CN]=工程管理器
GenericName[zh_TW]=專案管理員
Comment=Imports and edits custom make projects
Comment[bs]=Uvozi i uređuje korisnički prilagođene projekte
Comment[ca]=Importa i edita projectes personalitzats de Make
Comment[ca@valencia]=Importa i edita projectes personalitzats de Make
Comment[cs]=Importuje a upravuje vlastní projekty make
Comment[da]=Importerer og redigerer hjemmelavede make-projekter
Comment[de]=Importiert und bearbeitet benutzerdefinierte Make-Projekte
Comment[el]=Εισαγωγή και επεξεργασία έργων προσαρμοσμένου make
Comment[en_GB]=Imports and edits custom make projects
Comment[es]=Importa y edita proyectos make personalizados
Comment[et]=Kohandatud make'i projektide import ja redigeerimine
Comment[fa]=پروژه‌های make سفارشی را وارد و ویرایش می‌کند
Comment[fi]=Tuo ja muokkaa räätälöityjä make-projekteja
Comment[fr]=Importe et modifie des projets Make personnalisés
Comment[ga]=Iompórtáil tionscadail shaincheaptha make agus cuir iad in eagar
Comment[gl]=Importa e edita proxectos que usen un sistema make personalizado
Comment[hi]=मनपसंद मेक परियोजनाओं को संपादित व आयातित करने देता है
Comment[hne]=मनमाफिक मेक परियोजनाओं ल संपादित अउ आयातित करन देथे 
Comment[hu]=Egyéni make projektek importálása és szerkesztése
Comment[it]=Importa e modifica i progetti personalizzati di Make
Comment[ja]=カスタム Make プロジェクトのインポートと編集を行います
Comment[kk]=Өзгеше make жобаларын импорттау және өңдеу
Comment[ko]=사용자 정의 Make 프로젝트를 불러오고 관리합니다
Comment[lv]=Importē un rediģēt paštaisītus make projektus
Comment[nb]=Importerer og redigerer egendefinerte make-prosjekter
Comment[nds]=Egen Make-Projekten importeren un bewerken
Comment[ne]=अनुकूल निर्माण परियोजना आयात गर्दछ र सम्पादन गर्दछ
Comment[nl]=Importeert en bewerkt eigen make-projecten
Comment[pl]=Import i modyfikacja projektów używających własnych skryptów wykorzystujących make
Comment[pt]=Importa e edita projectos personalizados do make
Comment[pt_BR]=Importa e edita projetos make personalizados
Comment[ru]=Импорт и настройка собственных проектов make
Comment[sk]=Importuje a upravuje vlastné projekty make
Comment[sl]=Uvozi in ureja projekte po meri temelječe na Make
Comment[sv]=Importerar och redigerar egna projekt som använder Make
Comment[tr]=Özel make projelerini içeriye aktarır ve düzenler
Comment[ug]=ئىختىيارى make  قۇرۇلۇشلىرىنى تەھرىرلەيدۇ ۋە ئىمپورت قىلىدۇ
Comment[uk]=Імпортує і змінює проекти нетипових make
Comment[x-test]=xxImports and edits custom make projectsxx
Comment[zh_CN]=导入并编辑定制 make 工程
Comment[zh_TW]=匯入並編輯自訂的 make 專案
Icon=gear
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcustommakemanager
X-KDE-PluginInfo-Name=KDevCustomMakeManager
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-FileManager=CustomMake
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Interfaces=org.kdevelop.IBuildSystemManager,org.kdevelop.IProjectFileManager
X-KDevelop-IRequired=org.kdevelop.IMakeBuilder
X-KDevelop-Mode=NoGUI
X-KDevelop-ProjectFilesFilter=GNUmakefile,Makefile,makefile,GNUmakefile.*,Makefile.*,makefile.*
X-KDevelop-ProjectFilesFilterDescription=Makefiles

==> kdevelop-4.7.2.tar.xz: kdevelop-4.7.2/projectmanagers/custommake/kdevcustommakemanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Custom Makefile Project Manager
Name[bs]=Korisnički Makefile menadžer projekta
Name[ca]=Gestor de projecte personalitzat Makefile
Name[ca@valencia]=Gestor de projecte personalitzat Makefile
Name[da]=Projekthåndtering med hjemmelavet Makefile
Name[de]=Projektverwaltung mit eigenem Makefile
Name[el]=Διαχειριστής έργου προσαρμοσμένου Makefile
Name[en_GB]=Custom Makefile Project Manager
Name[es]=Gestor de proyectos Makefile personalizados
Name[et]=Kohandatud Makefile'i projektihaldur
Name[fi]=Räätälöity Makefile-projektinhallinta
Name[fr]=Gestionnaire de projets Makefiles personnalisés
Name[gl]=Xestor de proxectos con Makefile personalizado
Name[hu]=Egyéni makefájl projektkezelő
Name[it]=Gestore progetto Makefile personalizzato
Name[ja]=カスタム Makefile プロジェクトマネージャ
Name[kk]=Өзгеше Makefile жоба менеджері
Name[nb]=Prosjektstyring for egendefinerte Makefile-prosjekter
Name[nds]=Egen-Makefile-Projektpleger
Name[nl]=Aangepaste projectbeheerder voor makefile
Name[pl]=Zarządzanie własnym systemem budowania
Name[pt]=Gestor de Projectos de Makefiles Personalizadas
Name[pt_BR]=Gerenciador de Projeto personalizado do Makefile
Name[ru]=Управление проектами с собственным Makefile
Name[sk]=Správca projektu vlastného makefile
Name[sl]=Upravljalnik projekta z datoteko Makefile po meri
Name[sv]=Projekthantering av egna Make-filer
Name[tr]=Özel Makefile Proje Yönetici
Name[ug]=ئىختىيارى Makefile قۇرۇلۇش باشقۇرغۇ
Name[uk]=Керування проектами з власним Makefile
Name[x-test]=xxCustom Makefile Project Managerxx
Name[zh_CN]=自定义 Makefile 工程管理器
Name[zh_TW]=自訂 Makefile 專案管理員
GenericName=Project Manager
GenericName[bs]=Rukovodilac projekta
GenericName[ca]=Gestor de projectes
GenericName[ca@valencia]=Gestor de projectes
GenericName[cs]=Správce projektů
GenericName[da]=Projekthåndtering
GenericName[de]=Projektverwaltung
GenericName[el]=Διαχειριστής έργου
GenericName[en_GB]=Project Manager
GenericName[eo]=Projektadministrilo
GenericName[es]=Gestor de proyectos
GenericName[et]=Projektihaldur
GenericName[fi]=Projektinhallinta
GenericName[fr]=Gestionnaire de projets
GenericName[ga]=Bainisteoir Tionscadail
GenericName[gl]=Xestor de proxectos
GenericName[hu]=Projektkezelő
GenericName[it]=Gestore progetto
GenericName[ja]=プロジェクトマネージャ
GenericName[kk]=Жоба менеджері
GenericName[km]=កម្មវិធី​គ្រប់គ្រង​គម្រោង
GenericName[nb]=Prosjektbehandler
GenericName[nds]=Projektpleger
GenericName[nl]=Projectbeheerder
GenericName[nn]=Prosjekthandsamar
GenericName[pl]=Zarządzanie projektami
GenericName[pt]=Gestor de Projectos
GenericName[pt_BR]=Gerenciador de Projetos
GenericName[ru]=Управление проектами
GenericName[sk]=Správca projektu
GenericName[sl]=Upravljalnik projektov
GenericName[sv]=Projekthantering
GenericName[tr]=Proje Yönetici
GenericName[ug]=قۇرۇلۇش باشقۇرغۇچ
GenericName[uk]=Керування проектами
GenericName[x-test]=xxProject Managerxx
GenericName[zh_CN]=工程管理器
GenericName[zh_TW]=專案管理員
Comment=Imports and edits custom make projects
Comment[bs]=Uvozi i uređuje korisnički prilagođene projekte
Comment[ca]=Importa i edita projectes personalitzats de Make
Comment[ca@valencia]=Importa i edita projectes personalitzats de Make
Comment[cs]=Importuje a upravuje vlastní projekty make
Comment[da]=Importerer og redigerer hjemmelavede make-projekter
Comment[de]=Importiert und bearbeitet benutzerdefinierte Make-Projekte
Comment[el]=Εισαγωγή και επεξεργασία έργων προσαρμοσμένου make
Comment[en_GB]=Imports and edits custom make projects
Comment[es]=Importa y edita proyectos make personalizados
Comment[et]=Kohandatud make'i projektide import ja redigeerimine
Comment[fa]=پروژه‌های make سفارشی را وارد و ویرایش می‌کند
Comment[fi]=Tuo ja muokkaa räätälöityjä make-projekteja
Comment[fr]=Importe et modifie des projets Make personnalisés
Comment[ga]=Iompórtáil tionscadail shaincheaptha make agus cuir iad in eagar
Comment[gl]=Importa e edita proxectos que usen un sistema make personalizado
Comment[hi]=मनपसंद मेक परियोजनाओं को संपादित व आयातित करने देता है
Comment[hne]=मनमाफिक मेक परियोजनाओं ल संपादित अउ आयातित करन देथे 
Comment[hu]=Egyéni make projektek importálása és szerkesztése
Comment[it]=Importa e modifica i progetti personalizzati di Make
Comment[ja]=カスタム Make プロジェクトのインポートと編集を行います
Comment[kk]=Өзгеше make жобаларын импорттау және өңдеу
Comment[ko]=사용자 정의 Make 프로젝트를 불러오고 관리합니다
Comment[lv]=Importē un rediģēt paštaisītus make projektus
Comment[nb]=Importerer og redigerer egendefinerte make-prosjekter
Comment[nds]=Egen Make-Projekten importeren un bewerken
Comment[ne]=अनुकूल निर्माण परियोजना आयात गर्दछ र सम्पादन गर्दछ
Comment[nl]=Importeert en bewerkt eigen make-projecten
Comment[pl]=Import i modyfikacja projektów używających własnych skryptów wykorzystujących make
Comment[pt]=Importa e edita projectos personalizados do make
Comment[pt_BR]=Importa e edita projetos make personalizados
Comment[ru]=Импорт и настройка собственных проектов make
Comment[sk]=Importuje a upravuje vlastné projekty make
Comment[sl]=Uvozi in ureja projekte po meri temelječe na Make
Comment[sv]=Importerar och redigerar egna projekt som använder Make
Comment[tr]=Özel make projelerini içeriye aktarır ve düzenler
Comment[ug]=ئىختىيارى make  قۇرۇلۇشلىرىنى تەھرىرلەيدۇ ۋە ئىمپورت قىلىدۇ
Comment[uk]=Імпортує і змінює проекти нетипових make
Comment[x-test]=xxImports and edits custom make projectsxx
Comment[zh_CN]=导入并编辑定制 make 工程
Comment[zh_TW]=匯入並編輯自訂的 make 專案
Icon=gear
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcustommakemanager
X-KDE-PluginInfo-Name=KDevCustomMakeManager
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-FileManager=CustomMake
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Interfaces=org.kdevelop.IBuildSystemManager,org.kdevelop.IProjectFileManager
X-KDevelop-IRequired=org.kdevelop.IMakeBuilder
X-KDevelop-Mode=NoGUI
X-KDevelop-ProjectFilesFilter=GNUmakefile,Makefile,makefile,GNUmakefile.*,Makefile.*,makefile.*
X-KDevelop-ProjectFilesFilterDescription=Makefiles
